@@ -1,15 +1,23 @@
-const fs = require('fs-extra')
+const { readdir, readFile, writeFile, rm } = require('fs/promises')
 const sass = require('sass')
 const { join } = require('path')
 
 const dc_theme_dir = join(__dirname, '../themes')
 ;(async () => {
-  const files = await fs.readdir(dc_theme_dir)
+  const files = await readdir(dc_theme_dir)
+
+  // remove old files
+  await Promise.all(
+    files
+      .filter(f => f.includes('.css'))
+      .map(file => rm(join(dc_theme_dir, file)))
+  )
+
   const themes = files.filter(f => f.includes('.scss') && f.charAt(0) !== '_')
   try {
     const result = await Promise.all(
       themes.map(async theme => {
-        const theme_data = await fs.readFile(join(dc_theme_dir, theme), 'utf-8')
+        const theme_data = await readFile(join(dc_theme_dir, theme), 'utf-8')
 
         return new Promise((res, rej) => {
           sass.render(
@@ -23,7 +31,7 @@ const dc_theme_dir = join(__dirname, '../themes')
               if (err) return rej(err)
               try {
                 const resulting_filename = theme.replace('.scss', '.css')
-                await fs.writeFile(
+                await writeFile(
                   join(dc_theme_dir, resulting_filename),
                   result.css
                 )
