@@ -1,6 +1,6 @@
 import appConfig from './application-config'
 import { dirname, join } from 'path'
-import { screen } from 'electron'
+import { app, screen } from 'electron'
 
 export function appIcon() {
   const iconFormat = process.platform === 'win32' ? '.ico' : '.png'
@@ -18,12 +18,11 @@ export function windowDefaults() {
     targetFile = 'test.html'
     defaultWidth = 1100
   }
-  const {
-    height: screenHeight,
-    width: screenWidth,
-  } = screen.getPrimaryDisplay().workAreaSize
+  const { height: screenHeight, width: screenWidth } =
+    screen.getPrimaryDisplay().workAreaSize
   const headerHeight = 38
-  const defaultHeight = Math.min(700 + headerHeight, screenHeight)
+  // NOTE(maxph): we have a padding of 66px on the left of the buttons
+  const defaultHeight = Math.min(802 + headerHeight, screenHeight)
 
   const x = (screenWidth - defaultWidth) / 2
   const y = (screenHeight - defaultHeight) / 2
@@ -58,3 +57,16 @@ export function getAccountsPath() {
 export function getCustomThemesPath() {
   return join(getConfigPath(), 'custom-themes')
 }
+
+// this is used for temporary files (because core expects file paths, can not accept blobs directly yet)
+// used when sending file from webxdc and when pasting a file from clipboard
+export function getDraftTempDir() {
+  return join(app.getPath('temp'), 'chat.delta.desktop-draft')
+}
+
+export const supportedURISchemes = [
+  'OPENPGP4FPR:',
+  'MAILTO:',
+  'DCACCOUNT:',
+  'DCLOGIN:',
+]
