@@ -1,13 +1,13 @@
 import DeltaChatController from './controller'
 
 export default class SplitOut {
-  _controller: DeltaChatController
+  private controller: DeltaChatController
 
   constructor(controller: DeltaChatController) {
-    this._controller = controller
+    this.controller = controller
   }
 
-  get _dc() {
-    return this._controller._dc
+  get rpc() {
+    return this.controller.jsonrpcRemote.rpc
   }
 }
