@@ -7,14 +7,27 @@ const defaults: RC_Config = {
   'machine-readable-stacktrace': false,
   'multiple-instances': false,
   theme: undefined,
-  debug: false,
+  devmode: false,
   'translation-watch': false,
   'theme-watch': false,
+  minimized: false,
+  version: false,
+  v: false,
+  help: false,
+  h: false,
 }
 
 const config = rc('DeltaChat', defaults) as RC_Config
 
-if (config.debug) {
+if (config.version || config.v) {
+  config.version == true
+}
+
+if (config.help || config.h) {
+  config.help == true
+}
+
+if (config.devmode) {
   config['log-debug'] = true
   config['log-to-console'] = true
 }
