@@ -1,4 +1,5 @@
 import React from 'react'
+
 import MapComponent from './MapComponent'
 
 type ContextMenuProps = {
@@ -13,8 +14,10 @@ export default class ContextMenu extends React.Component<ContextMenuProps> {
   }
 
   onClick() {
-    this.props.onSetPoi(this.poiLabel.current.value)
-    this.poiLabel.current.value = ''
+    if (this.poiLabel.current) {
+      this.props.onSetPoi(this.poiLabel.current.value)
+      this.poiLabel.current.value = ''
+    }
   }
 
   render() {
