@@ -1,33 +1,27 @@
-import { DeltaBackend, sendMessageParams } from '../../delta-remote'
+import { T, C } from '@deltachat/jsonrpc-client'
 import React from 'react'
 import ReactDOMServer from 'react-dom/server'
 import ReactDOM from 'react-dom'
+import { Slider, Button, Collapse } from '@blueprintjs/core'
 import debounce from 'debounce'
 import mapboxgl from 'mapbox-gl'
-import { locationStore } from '../../stores/locations'
 import geojsonExtent from '@mapbox/geojson-extent'
 import moment from 'moment'
+
+import { locationStore } from '../../stores/locations'
 import formatRelativeTime from '../conversations/formatRelativeTime'
 import MapLayerFactory from './MapLayerFactory'
-import { Slider, Button, Collapse } from '@blueprintjs/core'
 import PopupMessage from './PopupMessage'
 import * as SessionStorage from '../helpers/SessionStorage'
-import { SettingsContext } from '../../contexts'
-import chatStore from '../../stores/chat'
-
 import { state as LocationStoreState } from '../../stores/locations'
-
 import ContextMenu from './ContextMenu'
-import {
-  FullChat,
-  MessageType,
-  JsonMessage,
-  JsonContact,
-  JsonLocations,
-} from '../../../shared/shared-types'
+import { BackendRemote, Type } from '../../backend-com'
+import { selectedAccountId } from '../../ScreenController'
+import { sendMessage } from '../helpers/ChatMethods'
+import { MessagesDisplayContext } from '../../contexts/MessagesDisplayContext'
 
 type MapData = {
-  contact: JsonContact
+  contact: Type.Contact
   pathLayerId: string
   pointsLayerId: string
   hidden: Boolean
@@ -36,10 +30,10 @@ type MapData = {
 
 type Point = [number, number]
 
-type Contact = JsonContact & { hidden?: boolean }
+type Contact = Type.Contact & { hidden?: boolean }
 
 type MapProps = {
-  selectedChat: FullChat
+  selectedChat: Type.FullChat
 }
 
 export default class MapComponent extends React.Component<
@@ -61,9 +55,10 @@ export default class MapComponent extends React.Component<
     this.getLocations,
     1000
   )
-  map: mapboxgl.Map
-  currentUserAddress: string
-  stateFromSession: boolean
+  map: mapboxgl.Map | undefined
+  popup_mount_node: HTMLDivElement | undefined
+  stateFromSession: boolean | undefined
+  currentUser: Type.Contact | undefined
   constructor(props: MapProps) {
     super(props)
     this.state = {
@@ -85,14 +80,23 @@ export default class MapComponent extends React.Component<
   }
 
   componentDidMount() {
+    this.init()
+  }
+
+  async init() {
+    const accountId = selectedAccountId()
+    this.currentUser = await BackendRemote.rpc.getContact(
+      accountId,
+      C.DC_CONTACT_ID_SELF
+    )
+
     const { selectedChat } = this.props
-    this.currentUserAddress = this.context.account.addr
     let mapSettings: { zoom: number; center: mapboxgl.LngLatLike } = {
       zoom: 4,
       center: [8, 48],
     } // <- default
     const savedData = SessionStorage.getItem(
-      this.currentUserAddress,
+      this.currentUser.address,
       `${selectedChat.id}_map`
     )
     if (savedData !== undefined) {
@@ -103,14 +107,16 @@ export default class MapComponent extends React.Component<
       this.setState(savedState)
       this.stateFromSession = true
     }
-    locationStore.setState({
-      selectedChat: selectedChat,
-      locations: [],
-      mapSettings: {
-        timestampFrom: this.getTimestampForRange(),
-        timestampTo: 0,
-      },
-    })
+    locationStore.setState(_state => {
+      return {
+        selectedChat: selectedChat,
+        locations: [],
+        mapSettings: {
+          timestampFrom: this.getTimestampForRange(),
+          timestampTo: 0,
+        },
+      }
+    }, 'init')
     mapboxgl.accessToken = MapLayerFactory.getAccessToken()
     this.map = new mapboxgl.Map({
       container: 'map',
@@ -129,17 +135,19 @@ export default class MapComponent extends React.Component<
   componentWillUnmount() {
     // save parts of the state we wanna keep
     const { selectedChat } = this.props
-    SessionStorage.storeItem(
-      this.currentUserAddress,
-      `${selectedChat.id}_map`,
-      {
-        savedMapSettings: this.map && {
-          zoom: this.map.getZoom(),
-          center: this.map.getCenter(),
-        },
-        savedState: this.state,
-      }
-    )
+    if (this.currentUser) {
+      SessionStorage.storeItem(
+        this.currentUser.address,
+        `${selectedChat.id}_map`,
+        {
+          savedMapSettings: this.map && {
+            zoom: this.map.getZoom(),
+            center: this.map.getCenter(),
+          },
+          savedState: this.state,
+        }
+      )
+    }
     locationStore.unsubscribe(this.onLocationsUpdate)
   }
 
@@ -163,15 +171,31 @@ export default class MapComponent extends React.Component<
   }
 
   renderLayers(locations: LocationStoreState['locations']) {
+    if (!this.currentUser) {
+      return
+    }
+    const map = this.map
+    if (!map) {
+      throw new Error('this.map is unset')
+    }
     // remove all layer since source update does not remove existing points
     this.removeAllLayer()
     this.mapDataStore.clear()
     const { selectedChat } = this.props
     let allPoints: Point[] = []
-    const currentContacts: JsonContact[] = []
+    const currentContacts: Type.Contact[] = []
     ;(this.mapDataStore as any).locationCount = locations.length
     if (locations.length > 0) {
-      selectedChat.contacts.map(contact => {
+      const contacts = selectedChat.contacts
+
+      if (
+        selectedChat.chatType !== C.DC_CHAT_TYPE_GROUP ||
+        !selectedChat.selfInGroup
+      ) {
+        // add current account to contact list to see own location and path
+        contacts.push(this.currentUser)
+      }
+      contacts.forEach(contact => {
         const locationsForContact = locations.filter(
           location =>
             location.contactId === contact.id && !location.isIndependent
@@ -189,19 +213,16 @@ export default class MapComponent extends React.Component<
         location => location.isIndependent && !location.marker
       )
       if (poiLocations.length > 0) {
-        if (!this.map.hasImage('poi-marker')) {
-          this.map.loadImage(
-            './icons/poi-marker.png',
-            (error: any, image: any) => {
-              if (!error) {
-                this.map.addImage('poi-marker', image)
-              }
+        if (!map.hasImage('poi-marker')) {
+          map.loadImage('./icons/poi-marker.png', (error: any, image: any) => {
+            if (!error) {
+              map.addImage('poi-marker', image)
             }
-          )
+          })
         }
         const poiLayer = MapLayerFactory.getPOILayer(poiLocations)
         this.mapDataStore.set('poi-layer', poiLayer)
-        this.map.addLayer(poiLayer)
+        map.addLayer(poiLayer)
       }
       const poiWithMarker = locations.filter(
         location => location.isIndependent && location.marker
@@ -211,11 +232,11 @@ export default class MapComponent extends React.Component<
         poiWithMarker.map(location => {
           const el = document.createElement('div')
           el.className = 'marker-icon'
-          el.innerHTML = location.marker
+          el.innerText = location.marker || '?'
           // make a marker for each feature and add to the map
           const m = new mapboxgl.Marker(el)
             .setLngLat([location.longitude, location.latitude])
-            .addTo(this.map)
+            .addTo(map)
           ;(m as any).location = location
           poiMarker.push(m)
         })
@@ -227,7 +248,7 @@ export default class MapComponent extends React.Component<
         this.changeMapStyle(this.state.mapStyle)
       } else {
         if (allPoints.length > 0) {
-          this.map.fitBounds(
+          map.fitBounds(
             geojsonExtent({ type: 'Point', coordinates: allPoints }),
             { padding: 100, maxZoom: this.maxZoomAfterFitBounds }
           )
@@ -236,7 +257,10 @@ export default class MapComponent extends React.Component<
     }
   }
 
-  renderContactLayer(contact: Contact, locationsForContact: JsonLocations) {
+  renderContactLayer(contact: Contact, locationsForContact: T.Location[]) {
+    if (!this.map) {
+      throw new Error('this.map is unset')
+    }
     let pointsForLayer: [number, number][] = []
     let lastPoint: todo | null = null
     if (locationsForContact && locationsForContact.length) {
@@ -257,7 +281,7 @@ export default class MapComponent extends React.Component<
         item => item.id === contact.id
       )
       if (existingContact) {
-        mapData.hidden = existingContact.hidden
+        mapData.hidden = existingContact.hidden || false
       }
       this.mapDataStore.set(contact.id, mapData)
       this.addOrUpdateLayerForContact(mapData, locationsForContact)
@@ -267,7 +291,9 @@ export default class MapComponent extends React.Component<
           extended: true,
         })
         const popup = new mapboxgl.Popup({ offset: 25 }).setHTML(
-          this.renderPopupMessage(contact.displayName, lastDate, null)
+          ReactDOMServer.renderToStaticMarkup(
+            this.renderPopupMessage(contact.displayName, lastDate, null)
+          )
         )
         if (mapData.marker) {
           // remove old marker
@@ -290,23 +316,27 @@ export default class MapComponent extends React.Component<
   }
 
   removeAllLayer() {
+    const map = this.map
+    if (!map) {
+      throw new Error('this.map is unset')
+    }
     if (this.mapDataStore.has('poi-marker')) {
       this.mapDataStore.get('poi-marker').map((m: todo) => m.remove())
       this.mapDataStore.delete('poi-marker')
     }
-    if (this.map.getLayer('poi-layer')) {
-      this.map.removeLayer('poi-layer')
-      this.map.removeSource('poi-layer')
+    if (map.getLayer('poi-layer')) {
+      map.removeLayer('poi-layer')
+      map.removeSource('poi-layer')
       this.mapDataStore.delete('poi-layer')
     }
     this.mapDataStore.forEach(mapDataItem => {
-      if (this.map.getLayer(mapDataItem.pathLayerId)) {
-        this.map.removeLayer(mapDataItem.pathLayerId)
-        this.map.removeSource(mapDataItem.pathLayerId)
+      if (map.getLayer(mapDataItem.pathLayerId)) {
+        map.removeLayer(mapDataItem.pathLayerId)
+        map.removeSource(mapDataItem.pathLayerId)
       }
-      if (this.map.getLayer(mapDataItem.pointsLayerId)) {
-        this.map.removeLayer(mapDataItem.pointsLayerId)
-        this.map.removeSource(mapDataItem.pointsLayerId)
+      if (map.getLayer(mapDataItem.pointsLayerId)) {
+        map.removeLayer(mapDataItem.pointsLayerId)
+        map.removeSource(mapDataItem.pointsLayerId)
       }
       if (mapDataItem.marker) {
         mapDataItem.marker.remove()
@@ -316,8 +346,11 @@ export default class MapComponent extends React.Component<
 
   addOrUpdateLayerForContact(
     mapData: MapData,
-    locationsForContact: JsonLocations
+    locationsForContact: T.Location[]
   ) {
+    if (!this.map) {
+      throw new Error('this.map is unset')
+    }
     if (!this.map.getSource(mapData.pathLayerId)) {
       this.addPathLayer(locationsForContact, mapData)
     } else {
@@ -341,7 +374,10 @@ export default class MapComponent extends React.Component<
     }
   }
 
-  addPathLayer(locationsForContact: JsonLocations, mapData: MapData) {
+  addPathLayer(locationsForContact: T.Location[], mapData: MapData) {
+    if (!this.map) {
+      throw new Error('this.map is unset')
+    }
     const source: mapboxgl.GeoJSONSourceRaw = {
       type: 'geojson',
       data: MapLayerFactory.getGeoJSONLineSourceData(
@@ -359,7 +395,10 @@ export default class MapComponent extends React.Component<
     }
   }
 
-  addPathJointsLayer(locationsForContact: JsonLocations, data: MapData) {
+  addPathJointsLayer(locationsForContact: T.Location[], data: MapData) {
+    if (!this.map) {
+      throw new Error('this.map is unset')
+    }
     const source: mapboxgl.GeoJSONSourceRaw = {
       type: 'geojson',
       data: MapLayerFactory.getGeoJSONPointsLayerSourceData(
@@ -377,44 +416,63 @@ export default class MapComponent extends React.Component<
   }
 
   async onMapClick(event: mapboxgl.MapMouseEvent & mapboxgl.EventData) {
-    let message: JsonMessage
-    const features = this.map.queryRenderedFeatures(event.point)
+    const map = this.map
+    if (!map) {
+      throw new Error('this.map is unset')
+    }
+    let message: Type.Message
+    const features = map.queryRenderedFeatures(event.point)
     const contactFeature = features.find(f => {
-      return f.properties.contact !== undefined || f.properties.isPoi
+      return (
+        f.properties &&
+        (f.properties.contact !== undefined || f.properties.isPoi)
+      )
     })
     if (contactFeature) {
-      if (contactFeature.properties.msgId) {
-        DeltaBackend.call(
-          'messageList.getMessage',
+      if (contactFeature.properties?.msgId) {
+        message = await BackendRemote.rpc.getMessage(
+          selectedAccountId(),
           contactFeature.properties.msgId
-        ).then((messageObj: MessageType) => {
-          if (messageObj) {
-            message = messageObj.msg
-          }
-          const markup = this.renderPopupMessage(
-            contactFeature.properties.contact,
-            formatRelativeTime(contactFeature.properties.reported * 1000, {
+        )
+
+        if (this.popup_mount_node) {
+          ReactDOM.unmountComponentAtNode(this.popup_mount_node)
+        }
+        this.popup_mount_node = document.createElement('div')
+        ReactDOM.render(
+          this.renderPopupMessage(
+            contactFeature.properties?.contact,
+            formatRelativeTime(contactFeature.properties?.reported * 1000, {
               extended: true,
             }),
             message
-          )
-          new mapboxgl.Popup({ offset: [0, -15] })
-            .setHTML(markup)
-            .setLngLat((contactFeature.geometry as any).coordinates)
-            .addTo(this.map)
-        })
+          ),
+          this.popup_mount_node
+        )
+
+        new mapboxgl.Popup({ offset: [0, -15] })
+          .setDOMContent(this.popup_mount_node)
+          .setLngLat((contactFeature.geometry as any).coordinates)
+          .addTo(map)
       }
     }
   }
 
   onMapRightClick(event: mapboxgl.MapMouseEvent & mapboxgl.EventData) {
+    if (!this.map) {
+      throw new Error('this.map is unset')
+    }
+    const contextMenu = ReactDOM.findDOMNode(this.contextMenu.current)
+    if (!contextMenu) {
+      throw new Error('contextMenu is unset')
+    }
     if (this.contextMenuPopup) {
       this.contextMenuPopup.remove()
     }
     this.poiLocation = event.lngLat
     this.contextMenuPopup = new mapboxgl.Popup({ offset: [0, -15] })
       .setLngLat(event.lngLat)
-      .setDOMContent(ReactDOM.findDOMNode(this.contextMenu.current))
+      .setDOMContent(contextMenu)
       .addTo(this.map)
       .on('close', () => {
         this.contextMenuPopup = null
@@ -428,12 +486,9 @@ export default class MapComponent extends React.Component<
       return
     }
     const latLng = Object.assign({}, this.poiLocation)
-    chatStore.dispatch({
-      type: 'SEND_MESSAGE',
-      payload: [
-        selectedChat.id,
-        { text: message, location: latLng } as sendMessageParams,
-      ],
+    sendMessage(selectedChat.id, {
+      text: message,
+      location: [latLng.lat, latLng.lng],
     })
 
     if (this.contextMenuPopup) {
@@ -448,6 +503,9 @@ export default class MapComponent extends React.Component<
     this.setState({ showPathLayer: !this.state.showPathLayer })
     const newVisibility = this.state.showPathLayer ? 'none' : 'visible'
     this.mapDataStore.forEach(mapDataItem => {
+      if (!this.map) {
+        throw new Error('this.map is unset')
+      }
       if (!mapDataItem.hidden && mapDataItem.contact) {
         this.map.setLayoutProperty(
           mapDataItem.pathLayerId,
@@ -464,6 +522,9 @@ export default class MapComponent extends React.Component<
   }
 
   changeMapStyle(style: 'default' | 'satellite') {
+    if (!this.map) {
+      throw new Error('this.map is unset')
+    }
     this.setState({ mapStyle: style })
     const visibility = style === 'satellite' ? 'visible' : 'none'
 
@@ -471,6 +532,9 @@ export default class MapComponent extends React.Component<
       this.map.addLayer(MapLayerFactory.getSatelliteMapLayer('satellite'))
       // move other layers to top
       this.mapDataStore.forEach(mapDataItem => {
+        if (!this.map) {
+          throw new Error('this.map is unset')
+        }
         if (this.map.getLayer(mapDataItem.pathLayerId)) {
           this.map.moveLayer(mapDataItem.pathLayerId)
         }
@@ -500,6 +564,10 @@ export default class MapComponent extends React.Component<
   }
 
   toggleContactLayer(contactId: number, isHidden: boolean) {
+    if (!this.map) {
+      throw new Error('this.map is unset')
+    }
+
     const mapDataItem = this.mapDataStore.get(contactId)
     const visibility = isHidden ? 'visible' : 'none' // set visibility to...
     if (!isHidden) {
@@ -538,6 +606,9 @@ export default class MapComponent extends React.Component<
   }
 
   setBoundToMarker() {
+    if (!this.map) {
+      throw new Error('this.map is unset')
+    }
     const markerCoordinates: Point[] = []
     this.mapDataStore.forEach(mapDataitem => {
       if (mapDataitem.marker && !mapDataitem.hidden) {
@@ -556,14 +627,20 @@ export default class MapComponent extends React.Component<
   renderPopupMessage(
     contactName: string,
     formattedDate: string,
-    message: JsonMessage
+    message: Type.Message | null
   ) {
-    return ReactDOMServer.renderToStaticMarkup(
-      <PopupMessage
-        username={contactName}
-        formattedDate={formattedDate}
-        message={message}
-      />
+    return (
+      <MessagesDisplayContext.Provider
+        value={
+          message ? { context: 'chat_map', chatId: message?.chatId } : null
+        }
+      >
+        <PopupMessage
+          username={contactName}
+          formattedDate={formattedDate}
+          message={message}
+        />
+      </MessagesDisplayContext.Provider>
     )
   }
 
@@ -573,7 +650,9 @@ export default class MapComponent extends React.Component<
         <input
           type='checkbox'
           name={'contact-' + contact.id}
-          onChange={() => this.toggleContactLayer(contact.id, contact.hidden)}
+          onChange={() =>
+            this.toggleContactLayer(contact.id, contact.hidden || false)
+          }
           checked={contact.hidden}
         />
         <label style={{ color: contact.color }}>{contact.displayName} </label>
@@ -584,6 +663,7 @@ export default class MapComponent extends React.Component<
   render() {
     return (
       <div className='map-wrapper'>
+        <div id='map' />
         <nav id='controls' className='map-overlay top'>
           <Button
             minimal
@@ -645,7 +725,6 @@ export default class MapComponent extends React.Component<
             </div>
           </Collapse>
         </nav>
-        <div id='map' />
         <div style={{ display: 'none' }}>
           <ContextMenu ref={this.contextMenu} onSetPoi={this.sendPoiMessage} />
         </div>
@@ -653,5 +732,3 @@ export default class MapComponent extends React.Component<
     )
   }
 }
-
-MapComponent.contextType = SettingsContext
